@@ -5,7 +5,7 @@ from typing import Dict, Type, Union, Tuple, Callable
 from time import sleep
 import importlib
 import subprocess
-import sys, json, os
+import sys, json, os, traceback
 from bson import json_util
 
 def run_with_executable(function_name, executable=None, args=[], kwargs={}, stdout=None, modulePaths=[]):
@@ -136,7 +136,8 @@ class Worker:
           print(f"Error: no callback funtion specified for job!")
 
     except Exception as ex:
-      job.error(f"Error: {ex}")
+      errtrace = traceback.format_exc()
+      job.error({"message": "Error: {ex}", "trace": str(errtrace)})
       print(f"Error: {ex}")
 
   def _run(self):
